Package com.pervasivecode.utils.concurrent.executors
-
Class Summary Class Description BlockingExecutorService Wrap a ThreadPoolExecutor with an ExecutorService implementation that blocks the thread attempting to submit a task when the task queue is full, rather than rejecting the submitted task (asThreadPoolExecutordoes).BlockingExecutorServiceConfig This object holds configuration information for aBlockingExecutorServiceinstance.BlockingExecutorServiceConfig.Builder This object will build aBlockingExecutorServiceConfiginstance. -
Enum Summary Enum Description BlockingExecutorService.Operation The kind of time-consuming activity that the BlockingExecutorService is engaged in, for use as a timer-type value in anMultistageStopwatchthat is measuring how much time is being spent in each activity.